About
=====

Welcome to the MetaSynth About Section. This section is meant to provide more information on the background and context of MetaSynth. 

.. toctree::
   :maxdepth: 1
   :caption: Sections:
   
   metasynth_in_detail
   contact
   license